==> quanyi-center-api-1.1.100-merge-20241213.095206-30-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/settlement/stat/RemoteSettlementOrderStatDayService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.settlement.stat;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.settlement.holo.SettlementHoloGoodsDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.holo.SettlementHoloStockDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDayDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDayFillDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDaySimpleDto;
import cn.com.duiba.quanyi.center.api.param.settlement.holo.SettlementHoloGoodsParam;
import cn.com.duiba.quanyi.center.api.param.settlement.holo.SettlementHoloPreviewParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayAmountParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayFillSearchParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayLockParam;

import java.util.List;
import java.util.Set;

/**
 * 结算订单统计-日纬度
 * @author kjj mybatis generator 
 * @date 2024-11-26
 */
@AdvancedFeignClient
public interface RemoteSettlementOrderStatDayService {

    /**
     * 根据主键批量查询
     * @param ids 主键ID
     * @return 结算订单统计-日纬度
     */
    List<SettlementOrderStatDaySimpleDto> selectSimpleByIds(Set<Long> ids);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 结算订单统计-日纬度
     */
    SettlementOrderStatDayDto selectById(Long id);

    /**
     * 批量锁定
     * @param list 锁定参数
     * @return 是否成功
     */
    boolean batchLock(List<SettlementOrderStatDayLockParam> list);

    /**
     * 批量解锁
     * @param settlementId 结算单ID
     * @param ids 主键
     * @return 是否成功
     */
    boolean batchUnlock(Long settlementId, List<Long> ids);

    /**
     * 分页查询结算单统计数据
     * @param param 分页参数
     * @return 结算订单统计-日纬度-回填金额
     */
    List<SettlementOrderStatDayFillDto> selectFillPage(SettlementOrderStatDayFillSearchParam param);

    /**
     * 根据ID批量查询
     * @param ids 主键
     * @return 结算订单统计-日纬度-回填金额
     */
    List<SettlementOrderStatDayFillDto> selectFillByIds(List<Long> ids);

    /**
     * 批量回填开票金额
     * @param list 参数
     * @return 是否成功
     */
    boolean batchFillInvoicedAmount(List<SettlementOrderStatDayAmountParam> list);

    /**
     * 批量回填回款金额
     * @param list 参数
     * @return 是否成功
     */
    boolean batchFillReceivedAmount(List<SettlementOrderStatDayAmountParam> list);

    /**
     * 根据条件分页查询
     * @param param
     * @return
     */
    List<SettlementHoloGoodsDto> selectGroupByDemandGoodsId(SettlementHoloGoodsParam param);

    /**
     * 根据条件查询总行数
     * @param param
     * @return
     */
    long selectCountGroupByDemandGoodsId(SettlementHoloGoodsParam param);

    /**
     * 查询预计金额记录
     * @param param
     * @return
     */
    List<SettlementOrderStatDayDto> selectExpectedAmountRecord(SettlementHoloPreviewParam param);


    /**
     * 根据demandGoodsId和stockId查询
     * @param param
     * @return
     */
    List<SettlementHoloStockDto> selectGroupByDemandGoodIdAndStockId(SettlementHoloGoodsParam param);

    /**
     * 查询累计超过期望金额记录
     * @param param
     * @return
     */
    SettlementOrderStatDayDto selectExpectedAmountRecordMore(SettlementHoloPreviewParam param);


    /**
     * 根据主键查询
     * @param ids 主键
     * @return 结算订单统计-日纬度
     */
    List<SettlementOrderStatDayDto> selectByIds(List<Long> ids);

    /**
     * 常规结算临时表
     * @param param
     * @return
     */
    void selectReceivableAmountRecord(SettlementHoloPreviewParam param);
}

==> quanyi-center-api-1.2.1-merge-20241216.070025-7-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/settlement/stat/RemoteSettlementOrderStatDayService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.settlement.stat;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.settlement.holo.SettlementHoloGoodsDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.holo.SettlementHoloStockDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDayDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDayFillDto;
import cn.com.duiba.quanyi.center.api.dto.settlement.stat.SettlementOrderStatDaySimpleDto;
import cn.com.duiba.quanyi.center.api.param.settlement.holo.SettlementHoloGoodsParam;
import cn.com.duiba.quanyi.center.api.param.settlement.holo.SettlementHoloPreviewParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayAmountParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayFillSearchParam;
import cn.com.duiba.quanyi.center.api.param.settlement.stat.SettlementOrderStatDayLockParam;

import java.util.List;
import java.util.Set;

/**
 * 结算订单统计-日纬度
 * @author kjj mybatis generator 
 * @date 2024-11-26
 */
@AdvancedFeignClient
public interface RemoteSettlementOrderStatDayService {

    /**
     * 根据主键批量查询
     * @param ids 主键ID
     * @return 结算订单统计-日纬度
     */
    List<SettlementOrderStatDaySimpleDto> selectSimpleByIds(List<Long> ids);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 结算订单统计-日纬度
     */
    SettlementOrderStatDayDto selectById(Long id);

    /**
     * 批量锁定
     * @param list 锁定参数
     * @return 是否成功
     */
    boolean batchLock(List<SettlementOrderStatDayLockParam> list);

    /**
     * 批量解锁
     * @param settlementId 结算单ID
     * @param ids 主键
     * @return 是否成功
     */
    boolean batchUnlock(Long settlementId, List<Long> ids);

    /**
     * 分页查询结算单统计数据
     * @param param 分页参数
     * @return 结算订单统计-日纬度-回填金额
     */
    List<SettlementOrderStatDayFillDto> selectFillPage(SettlementOrderStatDayFillSearchParam param);

    /**
     * 根据ID批量查询
     * @param ids 主键
     * @return 结算订单统计-日纬度-回填金额
     */
    List<SettlementOrderStatDayFillDto> selectFillByIds(List<Long> ids);

    /**
     * 批量回填开票金额
     * @param list 参数
     * @return 是否成功
     */
    boolean batchFillInvoicedAmount(List<SettlementOrderStatDayAmountParam> list);

    /**
     * 批量回填回款金额
     * @param list 参数
     * @return 是否成功
     */
    boolean batchFillReceivedAmount(List<SettlementOrderStatDayAmountParam> list);

    /**
     * 根据条件分页查询
     * @param param
     * @return
     */
    List<SettlementHoloGoodsDto> selectGroupByDemandGoodsId(SettlementHoloGoodsParam param);

    /**
     * 根据条件查询总行数
     * @param param
     * @return
     */
    long selectCountGroupByDemandGoodsId(SettlementHoloGoodsParam param);

    /**
     * 查询预计金额记录
     * @param param
     * @return
     */
    List<SettlementOrderStatDayDto> selectExpectedAmountRecord(SettlementHoloPreviewParam param);


    /**
     * 根据demandGoodsId和stockId查询
     * @param param
     * @return
     */
    List<SettlementHoloStockDto> selectGroupByDemandGoodIdAndStockId(SettlementHoloGoodsParam param);

    /**
     * 查询累计超过期望金额记录
     * @param param
     * @return
     */
    SettlementOrderStatDayDto selectExpectedAmountRecordMore(SettlementHoloPreviewParam param);


    /**
     * 根据主键查询
     * @param ids 主键
     * @return 结算订单统计-日纬度
     */
    List<SettlementOrderStatDayDto> selectByIds(List<Long> ids);

    /**
     * 常规结算临时表
     * @param param
     * @return
     */
    void selectReceivableAmountRecord(SettlementHoloPreviewParam param);
}
